MappingServiceSPARQLProcessor
=============================

.. currentmodule:: curies.mapping_service

.. autoclass:: MappingServiceSPARQLProcessor
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MappingServiceSPARQLProcessor.query

   .. rubric:: Methods Documentation

   .. automethod:: query
